@@ -21,7 +21,7 @@ MOUNTED_VOLUMES = "mounted_volumes"
 KUBERNETES_SECRETS = "kubernetes_secrets"
 KUBERNETES_TOLERATIONS = "kubernetes_tolerations"
 KUBERNETES_POD_ANNOTATIONS = "kubernetes_pod_annotations"
-PIPELINE_META_PROPERTIES = ["name", "description", "runtime"]
-# optional static prefix to be used when generating an object name for object storage
-COS_OBJECT_PREFIX = "cos_object_prefix"
-ELYRA_COMPONENT_PROPERTIES = [MOUNTED_VOLUMES, KUBERNETES_TOLERATIONS, KUBERNETES_POD_ANNOTATIONS]
+KUBERNETES_POD_LABELS = "kubernetes_pod_labels"
+DISABLE_NODE_CACHING = "disable_node_caching"
+KUBERNETES_SHARED_MEM_SIZE = "kubernetes_shared_mem_size"
+COS_OBJECT_PREFIX = "cos_object_prefix"  # optional static prefix to be used when generating object name for cos storage
