@@ -13,7 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-from abc import ABC
+from __future__ import annotations
+
 from abc import abstractmethod
 import ast
 import asyncio
@@ -21,6 +22,7 @@ import functools
 import os
 from pathlib import Path
 import time
+from typing import Any
 from typing import Dict
 from typing import List
 from typing import Optional
@@ -38,33 +40,40 @@ from urllib3.exceptions import MaxRetryError
 from elyra.metadata.manager import MetadataManager
 from elyra.pipeline.component import Component
 from elyra.pipeline.component_catalog import ComponentCache
+from elyra.pipeline.component_parameter import CustomSharedMemorySize
+from elyra.pipeline.component_parameter import DisableNodeCaching
+from elyra.pipeline.component_parameter import EnvironmentVariable
+from elyra.pipeline.component_parameter import KubernetesAnnotation
+from elyra.pipeline.component_parameter import KubernetesLabel
+from elyra.pipeline.component_parameter import KubernetesSecret
+from elyra.pipeline.component_parameter import KubernetesToleration
+from elyra.pipeline.component_parameter import VolumeMount
 from elyra.pipeline.pipeline import GenericOperation
 from elyra.pipeline.pipeline import Operation
 from elyra.pipeline.pipeline import Pipeline
-from elyra.pipeline.pipeline_constants import MOUNTED_VOLUMES
 from elyra.pipeline.runtime_type import RuntimeProcessorType
 from elyra.pipeline.runtime_type import RuntimeTypeResources
 from elyra.util.archive import create_temp_archive
 from elyra.util.cos import CosClient
-from elyra.util.kubernetes import is_valid_kubernetes_resource_name
 from elyra.util.path import get_expanded_path
 
 elyra_log_pipeline_info = os.getenv("ELYRA_LOG_PIPELINE_INFO", True)
 
 
 class PipelineProcessorRegistry(SingletonConfigurable):
-    _processors: Dict[str, "PipelineProcessor"] = {}
+    _processors: Dict[str, PipelineProcessor] = {}
 
     def __init__(self, **kwargs):
+        root_dir: Optional[str] = kwargs.pop("root_dir", None)
         super().__init__(**kwargs)
-        self.root_dir = get_expanded_path(kwargs.get("root_dir"))
+        self.root_dir = get_expanded_path(root_dir)
         # Register all known processors based on entrypoint configuration
         for processor in entrypoints.get_group_all("elyra.pipeline.processors"):
             try:
                 # instantiate an actual instance of the processor
-                processor_instance = processor.load()(self.root_dir, parent=kwargs.get("parent"))  # Load an instance
+                processor_instance = processor.load()(root_dir=self.root_dir, parent=kwargs.get("parent"))
                 self.log.info(
-                    f"Registering {processor.name} processor " f'"{processor.module_name}.{processor.object_name}"...'
+                    f"Registering {processor.name} processor '{processor.module_name}.{processor.object_name}'..."
                 )
                 self.add_processor(processor_instance)
             except Exception as err:
@@ -84,12 +93,15 @@ class PipelineProcessorRegistry(SingletonConfigurable):
         else:
             raise RuntimeError(f"Could not find pipeline processor '{processor_name}'")
 
+    def get_all_processors(self) -> List[PipelineProcessor]:
+        return list(self._processors.values())
+
     def is_valid_processor(self, processor_name: str) -> bool:
         return processor_name in self._processors.keys()
 
     def is_valid_runtime_type(self, runtime_type_name: str) -> bool:
         for processor in self._processors.values():
-            if processor.type.name == runtime_type_name:
+            if processor.type.name == runtime_type_name.upper():
                 return True
         return False
 
@@ -112,14 +124,18 @@ class PipelineProcessorManager(SingletonConfigurable):
     _registry: PipelineProcessorRegistry
 
     def __init__(self, **kwargs):
+        root_dir: Optional[str] = kwargs.pop("root_dir", None)
         super().__init__(**kwargs)
-        self.root_dir = get_expanded_path(kwargs.get("root_dir"))
-        self._registry = PipelineProcessorRegistry.instance()
+        self.root_dir = get_expanded_path(root_dir)
+        self._registry = PipelineProcessorRegistry.instance(root_dir=self.root_dir)
 
     def get_processor_for_runtime(self, runtime_name: str):
         processor = self._registry.get_processor(runtime_name)
         return processor
 
+    def get_all_processors(self) -> List[PipelineProcessor]:
+        return self._registry.get_all_processors()
+
     def is_supported_runtime(self, runtime_name: str) -> bool:
         return self._registry.is_valid_processor(runtime_name)
 
@@ -150,7 +166,7 @@ class PipelineProcessorManager(SingletonConfigurable):
         res = await asyncio.get_event_loop().run_in_executor(None, processor.process, pipeline)
         return res
 
-    async def export(self, pipeline, pipeline_export_format, pipeline_export_path, overwrite):
+    async def export(self, pipeline: Pipeline, pipeline_export_format: str, pipeline_export_path: str, overwrite: bool):
         processor = self.get_processor_for_runtime(pipeline.runtime)
 
         res = await asyncio.get_event_loop().run_in_executor(
@@ -159,16 +175,11 @@ class PipelineProcessorManager(SingletonConfigurable):
         return res
 
 
-class PipelineProcessorResponse(ABC):
+class PipelineProcessorResponse:
 
     _type: RuntimeProcessorType = None
     _name: str = None
 
-    def __init__(self, run_url, object_storage_url, object_storage_path):
-        self._run_url = run_url
-        self._object_storage_url = object_storage_url
-        self._object_storage_path = object_storage_path
-
     @property
     def type(self) -> str:  # Return the string value of the name so that JSON serialization works
         if self._type is None:
@@ -181,6 +192,19 @@ class PipelineProcessorResponse(ABC):
             raise NotImplementedError("_name must have a value!")
         return self._name
 
+    def to_json(self):
+        return {
+            "platform": self.type,
+        }
+
+
+class RuntimePipelineProcessorResponse(PipelineProcessorResponse):
+    def __init__(self, run_url, object_storage_url, object_storage_path):
+        super().__init__()
+        self._run_url = run_url
+        self._object_storage_url = object_storage_url
+        self._object_storage_path = object_storage_path
+
     @property
     def run_url(self):
         """
@@ -218,19 +242,15 @@ class PipelineProcessor(LoggingConfigurable):  # ABC
     _type: RuntimeProcessorType = None
     _name: str = None
 
-    root_dir = Unicode(allow_none=True)
+    root_dir: str = Unicode(allow_none=True)
 
-    enable_pipeline_info = Bool(
+    enable_pipeline_info: bool = Bool(
         config=True,
         default_value=(os.getenv("ELYRA_ENABLE_PIPELINE_INFO", "true").lower() == "true"),
         help="""Produces formatted logging of informational messages with durations
                                 (default=True). (ELYRA_ENABLE_PIPELINE_INFO env var)""",
     )
 
-    def __init__(self, root_dir, **kwargs):
-        super().__init__(**kwargs)
-        self.root_dir = root_dir
-
     @property
     def type(self):
         if self._type is None:
@@ -350,16 +370,13 @@ class PipelineProcessor(LoggingConfigurable):  # ABC
 
 
 class RuntimePipelineProcessor(PipelineProcessor):
-    def __init__(self, root_dir: str, **kwargs):
-        super().__init__(root_dir, **kwargs)
-
-    def _get_dependency_archive_name(self, operation: Operation) -> str:
+    def _get_dependency_archive_name(self, operation: GenericOperation) -> str:
         return f"{Path(operation.filename).stem}-{operation.id}.tar.gz"
 
-    def _get_dependency_source_dir(self, operation: Operation) -> str:
+    def _get_dependency_source_dir(self, operation: GenericOperation) -> str:
         return str(Path(self.root_dir) / Path(operation.filename).parent)
 
-    def _generate_dependency_archive(self, operation: Operation) -> Optional[str]:
+    def _generate_dependency_archive(self, operation: GenericOperation) -> Optional[str]:
         archive_artifact_name = self._get_dependency_archive_name(operation)
         archive_source_dir = self._get_dependency_source_dir(operation)
 
@@ -377,7 +394,7 @@ class RuntimePipelineProcessor(PipelineProcessor):
         return archive_artifact
 
     def _upload_dependencies_to_object_store(
-        self, runtime_configuration: str, pipeline_name: str, operation: Operation, prefix: str = ""
+        self, runtime_configuration: str, pipeline_name: str, operation: GenericOperation, prefix: str = ""
     ) -> None:
         """
         Create dependency archive for the generic operation identified by operation
@@ -500,7 +517,7 @@ class RuntimePipelineProcessor(PipelineProcessor):
         :return: dictionary containing environment name/value pairs
         """
 
-        envs: Dict = operation.env_vars.to_dict(logger=self.log)
+        envs: Dict = operation.env_vars.to_dict()
         envs["ELYRA_RUNTIME_ENV"] = self.name
 
         # set environment variables for Minio/S3 access, in the following order of precedence:
@@ -582,26 +599,34 @@ class RuntimePipelineProcessor(PipelineProcessor):
 
         return converted_list
 
-    def _get_volume_mounts(self, operation: Operation) -> Optional[Dict[str, str]]:
-        """
-        Loops through an Operation mounted volumes to re-format path and remove
-        invalid PVC names.
+    def add_disable_node_caching(self, instance: DisableNodeCaching, execution_object: Any, **kwargs) -> None:
+        """Add DisableNodeCaching info to the execution object for the given runtime processor"""
+        pass
 
-        :param operation: the operation to check for volume mounts
-        :return: dictionary of mount path to valid PVC names
-        """
-        volume_mounts_valid = {}
-        if operation.component_params.get(MOUNTED_VOLUMES):
-            volume_mounts = operation.component_params.get(MOUNTED_VOLUMES).to_dict()
-            for mount_path, pvc_name in volume_mounts.items():
-                # Ensure the PVC name is syntactically a valid Kubernetes resource name
-                if not is_valid_kubernetes_resource_name(pvc_name):
-                    self.log.warning(
-                        f"Ignoring invalid volume mount entry '{mount_path}': the PVC "
-                        f"name '{pvc_name}' is not a valid Kubernetes resource name."
-                    )
-                    continue
+    def add_custom_shared_memory_size(self, instance: CustomSharedMemorySize, execution_object: Any, **kwargs) -> None:
+        """Add CustomSharedMemorySize info to the execution object for the given runtime processor"""
+        pass
 
-                formatted_mount_path = f"/{mount_path.strip('/')}"
-                volume_mounts_valid[formatted_mount_path] = pvc_name
-        return volume_mounts_valid
+    def add_env_var(self, instance: EnvironmentVariable, execution_object: Any, **kwargs) -> None:
+        """Add EnvironmentVariable instance to the execution object for the given runtime processor"""
+        pass
+
+    def add_kubernetes_secret(self, instance: KubernetesSecret, execution_object: Any, **kwargs) -> None:
+        """Add KubernetesSecret instance to the execution object for the given runtime processor"""
+        pass
+
+    def add_mounted_volume(self, instance: VolumeMount, execution_object: Any, **kwargs) -> None:
+        """Add VolumeMount instance to the execution object for the given runtime processor"""
+        pass
+
+    def add_kubernetes_pod_annotation(self, instance: KubernetesAnnotation, execution_object: Any, **kwargs) -> None:
+        """Add KubernetesAnnotation instance to the execution object for the given runtime processor"""
+        pass
+
+    def add_kubernetes_pod_label(self, instance: KubernetesLabel, execution_object: Any, **kwargs) -> None:
+        """Add KubernetesLabel instance to the execution object for the given runtime processor"""
+        pass
+
+    def add_kubernetes_toleration(self, instance: KubernetesToleration, execution_object: Any, **kwargs) -> None:
+        """Add KubernetesToleration instance to the execution object for the given runtime processor"""
+        pass
