@@ -28,25 +28,19 @@ from traitlets.config import SingletonConfigurable
 from elyra.metadata.manager import MetadataManager
 from elyra.metadata.schema import SchemaManager
 from elyra.metadata.schemaspaces import Runtimes
-from elyra.pipeline.component import Component
 from elyra.pipeline.component_catalog import ComponentCache
-from elyra.pipeline.pipeline import DataClassJSONEncoder
-from elyra.pipeline.pipeline import KeyValueList
-from elyra.pipeline.pipeline import KubernetesSecret
+from elyra.pipeline.component_parameter import ElyraProperty
+from elyra.pipeline.component_parameter import ElyraPropertyJSONEncoder
+from elyra.pipeline.component_parameter import ElyraPropertyList
 from elyra.pipeline.pipeline import Operation
 from elyra.pipeline.pipeline import PIPELINE_CURRENT_SCHEMA
 from elyra.pipeline.pipeline import PIPELINE_CURRENT_VERSION
-from elyra.pipeline.pipeline import VolumeMount
 from elyra.pipeline.pipeline_constants import ENV_VARIABLES
-from elyra.pipeline.pipeline_constants import KUBERNETES_SECRETS
-from elyra.pipeline.pipeline_constants import MOUNTED_VOLUMES
 from elyra.pipeline.pipeline_constants import RUNTIME_IMAGE
 from elyra.pipeline.pipeline_definition import Node
 from elyra.pipeline.pipeline_definition import PipelineDefinition
 from elyra.pipeline.processor import PipelineProcessorManager
 from elyra.pipeline.runtime_type import RuntimeProcessorType
-from elyra.util.kubernetes import is_valid_kubernetes_key
-from elyra.util.kubernetes import is_valid_kubernetes_resource_name
 from elyra.util.path import get_expanded_path
 
 
@@ -107,7 +101,8 @@ class ValidationResponse(object):
                 "message": message,
                 "data": data,
             }
-            self._response["issues"].append(diagnostic)
+            if diagnostic not in self._response["issues"]:
+                self._response["issues"].append(diagnostic)
 
         if severity is ValidationSeverity.Error:
             self._has_fatal = True
@@ -118,8 +113,9 @@ class ValidationResponse(object):
 
 class PipelineValidationManager(SingletonConfigurable):
     def __init__(self, **kwargs):
+        root_dir: Optional[str] = kwargs.pop("root_dir", None)
         super().__init__(**kwargs)
-        self.root_dir = get_expanded_path(kwargs.get("root_dir"))
+        self.root_dir = get_expanded_path(root_dir)
 
     async def validate(self, pipeline: Dict) -> ValidationResponse:
         """
@@ -146,19 +142,17 @@ class PipelineValidationManager(SingletonConfigurable):
             return response
 
         # Validation can be driven from runtime_config since both runtime and pipeline_type can
-        # be derived from that and we should not use the 'runtime' and 'runtime_type' fields in
+        # be derived from that, and we should not use the 'runtime' and 'runtime_type' fields in
         # the pipeline.
         # Note: validation updates the pipeline definition with the correct values
         # of 'runtime' and 'runtime_type' obtained from 'runtime_config'.  We may want to move this
         # into PipelineDefinition, but then parsing tests have issues because parsing (tests) assume
         # no validation has been applied to the pipeline.
         runtime_config = primary_pipeline.runtime_config
-        if runtime_config is None:
-            runtime_config = "local"
 
         pipeline_runtime = PipelineValidationManager._determine_runtime(runtime_config)
         if PipelineProcessorManager.instance().is_supported_runtime(pipeline_runtime):
-            # Set the runtime since its derived from runtime_config and valid
+            # Set the runtime since it's derived from runtime_config and valid
             primary_pipeline.set("runtime", pipeline_runtime)
         else:
             response.add_message(
@@ -183,7 +177,7 @@ class PipelineValidationManager(SingletonConfigurable):
         if response.has_fatal:
             return response
 
-        # Set runtime_type since its derived from runtime_config, in case its needed
+        # Set runtime_type since it's derived from runtime_config, in case it's needed
         primary_pipeline.set("runtime_type", pipeline_type)
 
         await self._validate_node_properties(
@@ -196,21 +190,21 @@ class PipelineValidationManager(SingletonConfigurable):
         return response
 
     @staticmethod
-    def _determine_runtime(runtime_config: str) -> str:
+    def _determine_runtime(runtime_config: Optional[str]) -> str:
         """Derives the runtime (processor) from the runtime_config."""
-        # If not present or 'local', treat as special case.
-        if not runtime_config or runtime_config.upper() == RuntimeProcessorType.LOCAL.name:
+        # If runtime_config is not specified, treat as LOCAL.
+        if not runtime_config:
             return RuntimeProcessorType.LOCAL.name.lower()
 
         runtime_metadata = MetadataManager(schemaspace=Runtimes.RUNTIMES_SCHEMASPACE_ID).get(runtime_config)
         return runtime_metadata.schema_name
 
     @staticmethod
-    def _determine_runtime_type(runtime_config: str) -> str:
+    def _determine_runtime_type(runtime_config: Optional[str]) -> str:
         """Derives the runtime type (platform) from the runtime_config."""
-        # Pull the runtime_type (platform) from the runtime_config
-        # Need to special case 'local' runtime_config instances
-        if runtime_config.lower() == "local":
+        # Pull the runtime_type (platform) from the runtime_config.
+        # If not set, use LOCAL
+        if not runtime_config:
             runtime_type = RuntimeProcessorType.LOCAL
         else:
             runtime_metadata = MetadataManager(schemaspace=Runtimes.RUNTIMES_SCHEMASPACE_ID).get(runtime_config)
@@ -310,57 +304,62 @@ class PipelineValidationManager(SingletonConfigurable):
                 response.add_message(
                     severity=ValidationSeverity.Error,
                     message_type="invalidRuntime",
-                    message="Pipeline runtime platform is not compatible " "with selected runtime configuration.",
+                    message="Pipeline runtime platform is not compatible with selected runtime configuration.",
                     data={
                         "pipelineID": primary_pipeline_id,
                         "pipelineType": pipeline_type,
                         "pipelineRuntime": pipeline_runtime,
                     },
                 )
-            elif PipelineProcessorManager.instance().is_supported_runtime(pipeline_runtime):
-                component_list = await PipelineProcessorManager.instance().get_components(pipeline_runtime)
-                for component in component_list:
-                    supported_ops.append(component.op)
-
-                # Checks pipeline node types are compatible with the runtime selected
-                for sub_pipeline in pipeline_definition.pipelines:
-                    for node in sub_pipeline.nodes:
-                        if node.op not in ComponentCache.get_generic_component_ops() and pipeline_runtime == "local":
-                            response.add_message(
-                                severity=ValidationSeverity.Error,
-                                message_type="invalidNodeType",
-                                message="This pipeline contains at least one runtime-specific "
-                                "component, but pipeline runtime is 'local'. Specify a "
-                                "runtime config or remove runtime-specific components "
-                                "from the pipeline",
-                                data={"nodeID": node.id, "nodeOpName": node.op, "pipelineId": sub_pipeline.id},
-                            )
-                            break
-                        if node.type == "execution_node" and node.op not in supported_ops:
-                            response.add_message(
-                                severity=ValidationSeverity.Error,
-                                message_type="invalidNodeType",
-                                message="This component was not found in the catalog. Please add it "
-                                "to your component catalog or remove this node from the "
-                                "pipeline",
-                                data={
-                                    "nodeID": node.id,
-                                    "nodeOpName": node.op,
-                                    "nodeName": node.label,
-                                    "pipelineId": sub_pipeline.id,
-                                },
-                            )
             else:
-                response.add_message(
-                    severity=ValidationSeverity.Error,
-                    message_type="invalidRuntime",
-                    message="Unsupported pipeline runtime",
-                    data={
-                        "pipelineRuntime": pipeline_runtime,
-                        "pipelineType": pipeline_type,
-                        "pipelineId": primary_pipeline_id,
-                    },
-                )
+                processor_manager = PipelineProcessorManager.instance(root_dir=self.root_dir)
+                if processor_manager.is_supported_runtime(pipeline_runtime):
+                    component_list = await processor_manager.get_components(pipeline_runtime)
+                    for component in component_list:
+                        supported_ops.append(component.op)
+
+                    # Checks pipeline node types are compatible with the runtime selected
+                    for sub_pipeline in pipeline_definition.pipelines:
+                        for node in sub_pipeline.nodes:
+                            if (
+                                node.op not in ComponentCache.get_generic_component_ops()
+                                and pipeline_runtime == "local"
+                            ):
+                                response.add_message(
+                                    severity=ValidationSeverity.Error,
+                                    message_type="invalidNodeType",
+                                    message="This pipeline contains at least one runtime-specific "
+                                    "component, but pipeline runtime is 'local'. Specify a "
+                                    "runtime config or remove runtime-specific components "
+                                    "from the pipeline",
+                                    data={"nodeID": node.id, "nodeOpName": node.op, "pipelineId": sub_pipeline.id},
+                                )
+                                break
+                            if node.type == "execution_node" and node.op not in supported_ops:
+                                response.add_message(
+                                    severity=ValidationSeverity.Error,
+                                    message_type="invalidNodeType",
+                                    message="This component was not found in the catalog. Please add it "
+                                    "to your component catalog or remove this node from the "
+                                    "pipeline",
+                                    data={
+                                        "nodeID": node.id,
+                                        "nodeOpName": node.op,
+                                        "nodeName": node.label,
+                                        "pipelineId": sub_pipeline.id,
+                                    },
+                                )
+                else:
+                    response.add_message(
+                        severity=ValidationSeverity.Error,
+                        message_type="invalidRuntime",
+                        message="Unsupported pipeline runtime",
+                        data={
+                            "pipelineRuntime": pipeline_runtime,
+                            "pipelineType": pipeline_type,
+                            "pipelineId": primary_pipeline_id,
+                        },
+                    )
 
     async def _validate_node_properties(
         self,
@@ -386,7 +385,7 @@ class PipelineValidationManager(SingletonConfigurable):
             for node in pipeline.nodes:
                 if node.type == "execution_node":
                     if Operation.is_generic_operation(node.op):
-                        self._validate_generic_node_properties(
+                        await self._validate_generic_node_properties(
                             node=node, response=response, pipeline_runtime=pipeline_runtime
                         )
                     # Validate runtime components against specific node properties in component registry
@@ -398,7 +397,7 @@ class PipelineValidationManager(SingletonConfigurable):
                             pipeline_definition=pipeline_definition,
                         )
 
-    def _validate_generic_node_properties(self, node: Node, response: ValidationResponse, pipeline_runtime: str):
+    async def _validate_generic_node_properties(self, node: Node, response: ValidationResponse, pipeline_runtime: str):
         """
         Validate properties of a generic node
         :param node: the generic node to check
@@ -410,9 +409,7 @@ class PipelineValidationManager(SingletonConfigurable):
         image_name = node.get_component_parameter(RUNTIME_IMAGE)
         filename = node.get_component_parameter("filename")
         dependencies = node.get_component_parameter("dependencies")
-        env_vars = node.get_component_parameter(ENV_VARIABLES)
-        volumes = node.get_component_parameter(MOUNTED_VOLUMES)
-        secrets = node.get_component_parameter(KUBERNETES_SECRETS)
+        component_props = await self._get_component_properties(node.op)
 
         self._validate_filepath(
             node_id=node.id, node_label=node_label, property_name="filename", filename=filename, response=response
@@ -432,10 +429,12 @@ class PipelineValidationManager(SingletonConfigurable):
                         response=response,
                     )
 
-            if volumes:
-                self._validate_mounted_volumes(node.id, node_label, volumes, response=response)
-            if secrets:
-                self._validate_kubernetes_secrets(node.id, node_label, secrets, response=response)
+            for param in node.elyra_owned_properties:
+                required = self._is_required_property(component_props, param)
+                self._validate_elyra_owned_property(node.id, node.label, node, param, response, required)
+        else:
+            # Only env vars need to be validated for local runtime
+            self._validate_elyra_owned_property(node.id, node.label, node, ENV_VARIABLES, response)
 
         self._validate_label(node_id=node.id, node_label=node_label, response=response)
         if dependencies:
@@ -449,9 +448,6 @@ class PipelineValidationManager(SingletonConfigurable):
                     filename=dependency,
                     response=response,
                 )
-        if env_vars:
-            for env_var in env_vars:
-                self._validate_environmental_variables(node.id, node_label, env_var=env_var, response=response)
 
     async def _validate_custom_component_node_properties(
         self, node: Node, response: ValidationResponse, pipeline_definition: PipelineDefinition, pipeline_runtime: str
@@ -464,91 +460,86 @@ class PipelineValidationManager(SingletonConfigurable):
         :param pipeline_runtime: the pipeline runtime selected
         :return:
         """
-
-        component_list = await PipelineProcessorManager.instance().get_components(pipeline_runtime)
-        components = ComponentCache.to_canvas_palette(component_list)
-
         # Full dict of properties for the operation e.g. current params, optionals etc
-        component_property_dict = await self._get_component_properties(pipeline_runtime, components, node.op)
+        component_property_dict = await self._get_component_properties(node.op, pipeline_runtime)
+        current_parameters = component_property_dict["properties"]["component_parameters"]["properties"]
+
+        for param in node.elyra_owned_properties:
+            param_required = self._is_required_property(component_property_dict, param)
+            self._validate_elyra_owned_property(node.id, node.label, node, param, response, param_required)
 
         # List of just the current parameters for the component
-        current_parameter_defaults_list = list(
-            map(lambda x: str(x).replace("elyra_", ""), component_property_dict["current_parameters"].keys())
-        )
-
-        # Remove the non component_parameter jinja templated values we do not check against
-        current_parameter_defaults_list.remove("component_source")
-        current_parameter_defaults_list.remove("label")
-
-        volumes = node.get_component_parameter(MOUNTED_VOLUMES)
-        if volumes and MOUNTED_VOLUMES not in node.elyra_properties_to_skip:
-            self._validate_mounted_volumes(node.id, node.label, volumes, response=response)
-
-        for default_parameter in current_parameter_defaults_list:
+        parsed_parameters = [p for p in current_parameters.keys() if p not in node.elyra_owned_properties]
+        for default_parameter in parsed_parameters:
             node_param = node.get_component_parameter(default_parameter)
-            if self._is_required_property(component_property_dict, default_parameter):
-                if not node_param:
+            if not node_param or node_param.get("value") is None:
+                if self._is_required_property(component_property_dict, default_parameter):
                     response.add_message(
                         severity=ValidationSeverity.Error,
                         message_type="invalidNodeProperty",
-                        message="Node is missing required property.",
+                        message="Node is missing a value for a required property.",
                         data={"nodeID": node.id, "nodeName": node.label, "propertyName": default_parameter},
                     )
-                elif self._get_component_type(component_property_dict, default_parameter) == "inputpath":
-                    # Any component property with type `InputPath` will be a dictionary of two keys
-                    # "value": the node ID of the parent node containing the output
-                    # "option": the name of the key (which is an output) of the above referenced node
+            else:
+                if node_param.get("widget") == "inputpath":
+                    # The value of any component property with widget type `inputpath` will be a
+                    # dictionary of two keys:
+                    #   "value": the node ID of the parent node containing the output
+                    #   "option": the name of the key (which is an output) of the above referenced node
+                    inputpath_value = node_param.get("value")
                     if (
-                        not isinstance(node_param, dict)
-                        or len(node_param) != 2
-                        or set(node_param.keys()) != {"value", "option"}
+                        not isinstance(inputpath_value, dict)
+                        or len(inputpath_value) != 2
+                        or set(inputpath_value.keys()) != {"value", "option"}
                     ):
                         response.add_message(
                             severity=ValidationSeverity.Error,
                             message_type="invalidNodeProperty",
-                            message="Node has malformed `InputPath` parameter structure",
+                            message="Node parameter takes output from a parent, but parameter structure is malformed.",
                             data={"nodeID": node.id, "nodeName": node.label},
                         )
-                    node_ids = list(x.get("node_id_ref", None) for x in node.component_links)
+                    node_ids = [x.get("node_id_ref", None) for x in node.component_links]
                     parent_list = self._get_parent_id_list(pipeline_definition, node_ids, [])
-                    node_param_value = node_param.get("value")
-                    if node_param_value not in parent_list:
+                    upstream_node_id = inputpath_value.get("value")
+                    if upstream_node_id not in parent_list:
                         response.add_message(
                             severity=ValidationSeverity.Error,
                             message_type="invalidNodeProperty",
-                            message="Node contains an invalid inputpath reference. Please "
-                            "check your node-to-node connections",
+                            message="Node parameter takes output from a parent, but the referenced node is not a "
+                            "parent. Check your node-to-node connections.",
                             data={"nodeID": node.id, "nodeName": node.label},
                         )
-                elif isinstance(node_param, dict) and node_param.get("activeControl") == "NestedEnumControl":
-                    if not node_param.get("NestedEnumControl"):
-                        response.add_message(
-                            severity=ValidationSeverity.Error,
-                            message_type="invalidNodeProperty",
-                            message="Node contains an invalid reference to an node output. Please "
-                            "check the node properties are configured properly",
-                            data={"nodeID": node.id, "nodeName": node.label},
-                        )
-                    else:
-                        # TODO: Update this hardcoded check for xcom_push. This parameter is specific to a runtime
-                        # (Airflow). i.e. abstraction for byo validation?
-                        node_param_value = node_param["NestedEnumControl"].get("value")
-                        upstream_node = pipeline_definition.get_node(node_param_value)
+                    if pipeline_runtime == "airflow":
+                        # TODO: Update this runtime-specific check for xcom_push, i.e. abstraction for byo validation?
+                        upstream_node = pipeline_definition.get_node(upstream_node_id)
                         xcom_param = upstream_node.get_component_parameter("xcom_push")
                         if xcom_param:
-                            xcom_value = xcom_param.get("BooleanControl")
+                            xcom_value = xcom_param.get("value")
                             if not xcom_value:
                                 response.add_message(
                                     severity=ValidationSeverity.Error,
                                     message_type="invalidNodeProperty",
-                                    message="Node contains an invalid input reference. The parent "
-                                    "node does not have the xcom_push property enabled",
-                                    data={
-                                        "nodeID": node.id,
-                                        "nodeName": node.label,
-                                        "parentNodeID": upstream_node.label,
-                                    },
+                                    message="Node parameter takes output from a parent, but the parent "
+                                    "node does not have the xcom_push property enabled.",
+                                    data={"nodeID": node.id, "nodeName": node.label, "parentNodeID": upstream_node_id},
                                 )
+                elif node_param.get("widget") == "file":
+                    filename = node_param.get("value")
+                    if filename:
+                        self._validate_filepath(
+                            node_id=node.id,
+                            node_label=node.label,
+                            property_name=default_parameter,
+                            filename=filename,
+                            response=response,
+                        )
+                    elif self._is_required_property(component_property_dict, default_parameter):
+                        response.add_message(
+                            severity=ValidationSeverity.Error,
+                            message_type="invalidNodeProperty",
+                            message="Node is missing a value for a required property.",
+                            data={"nodeID": node.id, "nodeName": node.label, "propertyName": default_parameter},
+                        )
 
     def _validate_container_image_name(
         self, node_id: str, node_label: str, image_name: str, response: ValidationResponse
@@ -621,85 +612,52 @@ class PipelineValidationManager(SingletonConfigurable):
                 },
             )
 
-    def _validate_mounted_volumes(
-        self, node_id: str, node_label: str, volumes: List[VolumeMount], response: ValidationResponse
+    def _validate_elyra_owned_property(
+        self,
+        node_id: str,
+        node_label: str,
+        node: Node,
+        param_name: str,
+        response: ValidationResponse,
+        required: bool = False,
     ) -> None:
         """
         Checks the format of mounted volumes to ensure they're in the correct form
         e.g. foo/path=pvc_name
         :param node_id: the unique ID of the node
         :param node_label: the given node name or user customized name/label of the node
-        :param volumes: a KeyValueList of volumes to check
+        :param param_name: the name of the parameter to check
         :param response: ValidationResponse containing the issue list to be updated
         """
-        for volume in volumes:
-            # Ensure the PVC name is syntactically a valid Kubernetes resource name
-            if not is_valid_kubernetes_resource_name(volume.pvc_name):
+
+        def validate_elyra_owned_property(elyra_property):
+            for msg in elyra_property.get_all_validation_errors():
                 response.add_message(
                     severity=ValidationSeverity.Error,
-                    message_type="invalidVolumeMount",
-                    message=f"PVC name '{volume.pvc_name}' is not a valid Kubernetes resource name.",
+                    message_type=f"invalid{elyra_property.__class__.__name__}",
+                    message=msg,
                     data={
                         "nodeID": node_id,
                         "nodeName": node_label,
-                        "propertyName": MOUNTED_VOLUMES,
-                        "value": KeyValueList.to_str(volume.path, volume.pvc_name),
+                        "propertyName": param_name,
+                        "value": elyra_property.get_value_for_display(),
                     },
                 )
 
-    def _validate_kubernetes_secrets(
-        self, node_id: str, node_label: str, secrets: List[KubernetesSecret], response: ValidationResponse
-    ) -> None:
-        """
-        Checks the format of Kubernetes secrets to ensure they're in the correct form
-        e.g. FOO=SECRET_NAME:KEY
-        :param node_id: the unique ID of the node
-        :param node_label: the given node name or user customized name/label of the node
-        :param secrets: a KeyValueList of secrets to check
-        :param response: ValidationResponse containing the issue list to be updated
-        """
-        for secret in secrets:
-            if not secret.name or not secret.key:
-                response.add_message(
-                    severity=ValidationSeverity.Error,
-                    message_type="invalidKubernetesSecret",
-                    message=f"Environment variable '{secret.env_var}' has an improperly formatted representation of "
-                    f"secret name and key.",
-                    data={
-                        "nodeID": node_id,
-                        "nodeName": node_label,
-                        "propertyName": KUBERNETES_SECRETS,
-                        "value": KeyValueList.to_str(secret.env_var, f"{(secret.name or '')}:{(secret.key or '')}"),
-                    },
-                )
-                continue
-
-            # Ensure the secret name is syntactically a valid Kubernetes resource name
-            if not is_valid_kubernetes_resource_name(secret.name):
-                response.add_message(
-                    severity=ValidationSeverity.Error,
-                    message_type="invalidKubernetesSecret",
-                    message=f"Secret name '{secret.name}' is not a valid Kubernetes resource name.",
-                    data={
-                        "nodeID": node_id,
-                        "nodeName": node_label,
-                        "propertyName": KUBERNETES_SECRETS,
-                        "value": KeyValueList.to_str(secret.env_var, f"{secret.name}:{secret.key}"),
-                    },
-                )
-            # Ensure the secret key is a syntactically valid Kubernetes key
-            if not is_valid_kubernetes_key(secret.key):
-                response.add_message(
-                    severity=ValidationSeverity.Error,
-                    message_type="invalidKubernetesSecret",
-                    message=f"Key '{secret.key}' is not a valid Kubernetes secret key.",
-                    data={
-                        "nodeID": node_id,
-                        "nodeName": node_label,
-                        "propertyName": KUBERNETES_SECRETS,
-                        "value": KeyValueList.to_str(secret.env_var, f"{secret.name}:{secret.key}"),
-                    },
-                )
+        param_value = node.get_component_parameter(param_name)
+        if param_value:
+            if isinstance(param_value, ElyraPropertyList):
+                for prop in param_value:
+                    validate_elyra_owned_property(prop)
+            elif isinstance(param_value, ElyraProperty):
+                validate_elyra_owned_property(param_value)
+        elif required:
+            response.add_message(
+                severity=ValidationSeverity.Error,
+                message_type="invalidNodeProperty",
+                message="Required property value is missing.",
+                data={"nodeID": node.id, "nodeName": node_label, "propertyName": param_name},
+            )
 
     def _validate_filepath(
         self,
@@ -746,7 +704,7 @@ class PipelineValidationManager(SingletonConfigurable):
                 response.add_message(
                     severity=ValidationSeverity.Error,
                     message_type="invalidFilePath",
-                    message="Property(wildcard) has an invalid path to a file/dir" " or the file/dir does not exist.",
+                    message="Property(wildcard) has an invalid path to a file/dir or the file/dir does not exist.",
                     data={
                         "nodeID": node_id,
                         "nodeName": node_label,
@@ -754,7 +712,7 @@ class PipelineValidationManager(SingletonConfigurable):
                         "value": normalized_path,
                     },
                 )
-        elif not os.path.exists(normalized_path):
+        elif not os.path.exists(normalized_path) or not os.path.isfile(normalized_path):
             response.add_message(
                 severity=ValidationSeverity.Error,
                 message_type="invalidFilePath",
@@ -767,26 +725,6 @@ class PipelineValidationManager(SingletonConfigurable):
                 },
             )
 
-    def _validate_environmental_variables(
-        self, node_id: str, node_label: str, env_var: str, response: ValidationResponse
-    ) -> None:
-        """
-        Checks the format of the env var to ensure its in the correct form
-        e.g. FOO = 'BAR'
-        :param node_id: the unique ID of the node
-        :param node_label: the given node name or user customized name/label of the node
-        :param env_var: the env_var key value pair to check
-        :param response: ValidationResponse containing the issue list to be updated
-        """
-        result = [x.strip(" '\"") for x in env_var.split("=", 1)]
-        if len(result) != 2:
-            response.add_message(
-                severity=ValidationSeverity.Error,
-                message_type="invalidEnvPair",
-                message="Property has an improperly formatted env variable key value pair.",
-                data={"nodeID": node_id, "nodeName": node_label, "propertyName": ENV_VARIABLES, "value": env_var},
-            )
-
     def _validate_label(self, node_id: str, node_label: str, response: ValidationResponse) -> None:
         """
         KFP specific check for the label name when constructing the node operation using dsl
@@ -844,7 +782,7 @@ class PipelineValidationManager(SingletonConfigurable):
         :param response: ValidationResponse containing the issue list to be updated
         :param pipeline: A dictionary describing the pipeline
         """
-        pipeline_json = json.loads(json.dumps(pipeline, cls=DataClassJSONEncoder))
+        pipeline_json = json.loads(json.dumps(pipeline, cls=ElyraPropertyJSONEncoder))
 
         graph = nx.DiGraph()
 
@@ -895,7 +833,7 @@ class PipelineValidationManager(SingletonConfigurable):
         :param node_id: the node ID of the node
         :return: the pipeline ID of where the node is located
         """
-        pipeline_json = json.loads(json.dumps(pipeline, cls=DataClassJSONEncoder))
+        pipeline_json = json.loads(json.dumps(pipeline, cls=ElyraPropertyJSONEncoder))
         for single_pipeline in pipeline_json["pipelines"]:
             node_list = single_pipeline["nodes"]
             for node in node_list:
@@ -903,26 +841,25 @@ class PipelineValidationManager(SingletonConfigurable):
                     return single_pipeline["id"]
         return None
 
-    async def _get_component_properties(self, pipeline_runtime: str, components: dict, node_op: str) -> Dict:
+    async def _get_component_properties(self, node_op: str, pipeline_runtime: Optional[str] = None) -> Dict:
         """
         Retrieve the full dict of properties associated with the node_op
-        :param components: list of components associated with the pipeline runtime being used e.g. kfp, airflow
         :param node_op: the node operation e.g. execute-notebook-node
         :return: a list of property names associated with the node op
         """
+        if not pipeline_runtime:
+            pipeline_runtime = RuntimeProcessorType.LOCAL.name.lower()
+
+        # list of components associated with the pipeline runtime being used
+        component_list = await PipelineProcessorManager.instance().get_components(pipeline_runtime)
+        components = ComponentCache.to_canvas_palette(component_list)
 
-        if node_op == "execute-notebook-node":
-            node_op = "notebooks"
-        elif node_op == "execute-r-node":
-            node_op = "r-script"
-        elif node_op == "execute-python-node":
-            node_op = "python-script"
         for category in components["categories"]:
             for node_type in category["node_types"]:
                 if node_op == node_type["op"]:
-                    component: Component = await PipelineProcessorManager.instance().get_component(
-                        pipeline_runtime, node_op
-                    )
+                    component = await PipelineProcessorManager.instance().get_component(pipeline_runtime, node_op)
+                    if not component:  # component is generic; retrieve using static method
+                        component = ComponentCache.get_generic_component_from_op(node_op)
                     component_properties = ComponentCache.to_canvas_properties(component)
                     return component_properties
 
@@ -936,7 +873,7 @@ class PipelineValidationManager(SingletonConfigurable):
         :return: a string representing the name of the node
         """
         node_name_list = []
-        pipeline_json = json.loads(json.dumps(pipeline, cls=DataClassJSONEncoder))
+        pipeline_json = json.loads(json.dumps(pipeline, cls=ElyraPropertyJSONEncoder))
         for node_id in node_id_list:
             found = False
             for single_pipeline in pipeline_json["pipelines"]:
@@ -962,7 +899,7 @@ class PipelineValidationManager(SingletonConfigurable):
         if link_ids is None:
             return None
 
-        pipeline_json = json.loads(json.dumps(pipeline, cls=DataClassJSONEncoder))
+        pipeline_json = json.loads(json.dumps(pipeline, cls=ElyraPropertyJSONEncoder))
         node_labels = []
         for link_id in link_ids:
             for single_pipeline in pipeline_json["pipelines"]:
@@ -1001,32 +938,17 @@ class PipelineValidationManager(SingletonConfigurable):
 
     def _is_required_property(self, property_dict: dict, node_property: str) -> bool:
         """
-        Determine whether or not a component parameter is required to function correctly
+        Determine whether a component parameter is required to function correctly
         :param property_dict: the dictionary for the component
         :param node_property: the component property to check
         :return:
         """
-        node_op_parameter_list = property_dict["uihints"]["parameter_info"]
-        for parameter in node_op_parameter_list:
-            if parameter["parameter_ref"] == f"elyra_{node_property}":
-                return parameter["data"]["required"]
-        return False
+        required_parameters = property_dict["properties"]["component_parameters"].get("required")
+        if required_parameters:
+            return node_property in required_parameters
 
-    def _get_component_type(self, property_dict: dict, node_property: str, control_id: str = "") -> Optional[str]:
-        """
-        Helper function to determine the type of a node property
-        :param property_dict: a dictionary containing the full list of property parameters and descriptions
-        :param node_property: the property to look for
-        :param control_id: when using OneOfControl, include the control_id to retrieve the correct format
-        :return: the data type associated with node_property, defaults to 'string'
-        """
-        for prop in property_dict["uihints"]["parameter_info"]:
-            if prop["parameter_ref"] == f"elyra_{node_property}":
-                if control_id:
-                    return prop["data"]["controls"][control_id].get("format", "string")
-                else:
-                    return prop["data"].get("format", "string")
-        return None
+        param = property_dict["properties"]["component_parameters"]["properties"].get(node_property, {})
+        return param.get("required", False)
 
     def _get_parent_id_list(
         self, pipeline_definition: PipelineDefinition, node_id_list: list, parent_list: list
