@@ -158,6 +158,40 @@ def test_manager_add_display_name(tests_manager, schemaspace_location):
         tests_manager.metadata_store.fetch_instances(metadata_name)
 
 
+@pytest.mark.parametrize(
+    "complex_string, valid",
+    [
+        ("", False),
+        (" ", False),
+        (" starting-whitespace", False),
+        ("ending-whitespace ", False),
+        (" whitespace-both-ends ", False),
+        ("whitespace in between", True),
+        ("no-whitespace", True),
+    ],
+)
+def test_manager_complex_string_schema(tests_manager, schemaspace_location, complex_string, valid):
+    metadata_name = "valid_metadata_instance"
+    metadata_dict = {**valid_metadata_json}
+    metadata_dict["metadata"]["string_complex_test"] = complex_string
+    metadata = Metadata.from_dict(METADATA_TEST_SCHEMASPACE_ID, metadata_dict)
+
+    if not valid:
+        with pytest.raises(ValidationError):
+            tests_manager.create(metadata_name, metadata)
+
+    else:
+        instance = tests_manager.create(metadata_name, metadata)
+        assert instance.metadata.get("string_complex_test") == complex_string
+
+        # And finally, remove it.
+        tests_manager.remove(metadata_name)
+
+        # Verify removal using metadata_store
+        with pytest.raises(MetadataNotFoundError):
+            tests_manager.metadata_store.fetch_instances(metadata_name)
+
+
 def test_manager_get_include_invalid(tests_manager):
     metadata_list = tests_manager.get_all(include_invalid=False)
     assert len(metadata_list) == 2
@@ -655,6 +689,37 @@ def test_manager_hierarchy_remove(tests_hierarchy_manager, factory_location, sha
     assert byo_1.resource.startswith(str(factory_location))
 
 
+@pytest.mark.skipif(
+    os.getenv("TEST_VALIDATION_PERFORMANCE", "0") != "1",
+    reason="test_validation_performance - enable via env TEST_VALIDATION_PERFORMANCE=1",
+)
+def test_validation_performance():
+    import psutil
+
+    metadata_mgr = MetadataManager(schemaspace=METADATA_TEST_SCHEMASPACE)
+    metadata_dict = {**valid_metadata_json}
+    metadata = Metadata.from_dict(METADATA_TEST_SCHEMASPACE_ID, metadata_dict)
+
+    process = psutil.Process(os.getpid())
+    # warm up
+    metadata_mgr.validate("perf_test", metadata)
+
+    iterations = 10000
+    memory_start = process.memory_info()
+    t0 = time.time()
+    for _ in range(0, iterations):
+        metadata_mgr.validate("perf_test", metadata)
+
+    t1 = time.time()
+    memory_end = process.memory_info()
+    diff = (memory_end.rss - memory_start.rss) / 1024
+    print(
+        f"Memory: {diff:,} kb, Start: {memory_start.rss / 1024 / 1024:,.3f} mb, "
+        f"End: {memory_end.rss / 1024 / 1024:,.3f} mb., "
+        f"Elapsed time: {t1-t0:.3f}s over {iterations} iterations."
+    )
+
+
 # ########################## MetadataStore Tests ###########################
 def test_store_schemaspace(store_manager, schemaspace_location):
     # Delete the metadata dir contents and attempt listing metadata
