@@ -19,14 +19,18 @@ from conftest import AIRFLOW_TEST_OPERATOR_CATALOG
 import pytest
 
 from elyra.pipeline import pipeline_constants
-from elyra.pipeline.pipeline import KeyValueList
-from elyra.pipeline.pipeline import VolumeMount
+from elyra.pipeline.component import Component
+from elyra.pipeline.component_parameter import ElyraProperty
+from elyra.pipeline.component_parameter import ElyraPropertyList
+from elyra.pipeline.component_parameter import KubernetesSecret
+from elyra.pipeline.pipeline_constants import DISABLE_NODE_CACHING
 from elyra.pipeline.pipeline_constants import ENV_VARIABLES
 from elyra.pipeline.pipeline_constants import KUBERNETES_SECRETS
 from elyra.pipeline.pipeline_constants import MOUNTED_VOLUMES
 from elyra.pipeline.pipeline_constants import RUNTIME_IMAGE
 from elyra.pipeline.pipeline_definition import Node
 from elyra.pipeline.pipeline_definition import PipelineDefinition
+from elyra.pipeline.runtime_type import RuntimeProcessorType
 from elyra.tests.pipeline.util import _read_pipeline_resource
 
 
@@ -108,61 +112,37 @@ def test_updates_to_nodes_updates_pipeline_definition():
 
 
 def test_envs_to_dict():
-    test_list = ["TEST= one", "TEST_TWO=two ", "TEST_THREE =", " TEST_FOUR=1", "TEST_FIVE = fi=ve "]
-    test_dict_correct = {"TEST": "one", "TEST_TWO": "two", "TEST_FOUR": "1", "TEST_FIVE": "fi=ve"}
-    assert KeyValueList(test_list).to_dict() == test_dict_correct
+    env_variables = [
+        {"env_var": "TEST", "value": " one"},
+        {"env_var": "TEST_TWO", "value": "two"},
+        {"env_var": "TEST_THREE", "value": ""},
+        {"env_var": "TEST_FOUR", "value": "1"},
+        {"env_var": "TEST_TWO"},
+    ]
+    converted_list = ElyraProperty.create_instance("env_vars", env_variables)
+    test_dict_correct = {"TEST": "one", "TEST_TWO": "two", "TEST_FOUR": "1"}
+    assert converted_list.to_dict() == test_dict_correct
 
 
-def test_env_dict_to_list():
-    test_dict = {"TEST": "one", "TEST_TWO": "two", "TEST_FOUR": "1"}
-    test_list_correct = ["TEST=one", "TEST_TWO=two", "TEST_FOUR=1"]
-    assert KeyValueList.from_dict(test_dict) == test_list_correct
+def test_elyra_property_list_difference():
+    env_variables = [
+        {"env_var": "TEST", "value": "one"},
+        {"env_var": "TEST_TWO", "value": "two"},
+        {"env_var": "TEST_FOUR", "value": "1"},
+    ]
+    converted_list = ElyraProperty.create_instance("env_vars", env_variables)
+    empty_list = ElyraPropertyList.difference(converted_list, converted_list)
+    assert empty_list == []
 
 
-def test_convert_kv_properties(monkeypatch):
-    kv_test_property_name = "kv_test_property"
+@pytest.mark.parametrize("catalog_instance", [AIRFLOW_TEST_OPERATOR_CATALOG], indirect=True)
+def test_propagate_pipeline_default_properties(monkeypatch, catalog_instance):
+    kv_dict = {"var1": "var1", "var2": "var2", "var3": "var_three"}
     pipeline_json = _read_pipeline_resource("resources/sample_pipelines/pipeline_valid_with_pipeline_default.json")
 
-    # Mock get_kv_properties() to ensure the "kv_test_property" variable is included in the list
-    mock_kv_property_list = [pipeline_constants.ENV_VARIABLES, kv_test_property_name]
-    monkeypatch.setattr(PipelineDefinition, "get_kv_properties", mock.Mock(return_value=mock_kv_property_list))
-
-    # Mock set_elyra_properties_to_skip() so that a ComponentCache instance is not created unnecessarily
-    monkeypatch.setattr(Node, "set_elyra_properties_to_skip", mock.Mock(return_value=None))
-
-    pipeline_definition = PipelineDefinition(pipeline_definition=pipeline_json)
-
-    node = None
-    for node in pipeline_definition.pipeline_nodes:
-        if node.op == "execute-notebook-node":  # assign the generic node to the node variable
-            break
-    pipeline_defaults = pipeline_definition.primary_pipeline.get_property(pipeline_constants.PIPELINE_DEFAULTS)
-
-    for kv_property in mock_kv_property_list:
-        assert isinstance(node.get_component_parameter(kv_property), KeyValueList)
-        assert isinstance(pipeline_defaults[kv_property], KeyValueList)
-
-    # Ensure a non-list property is not converted to a KeyValueList
-    assert not isinstance(
-        pipeline_definition.primary_pipeline.get_property(pipeline_constants.RUNTIME_IMAGE), KeyValueList
-    )
-
-    # Ensure plain list property is not converted to a KeyValueList
-    assert not isinstance(node.get_component_parameter("outputs"), KeyValueList)
-
-
-def test_propagate_pipeline_default_properties(monkeypatch):
-    kv_list_correct = ["var1=var1", "var2=var2", "var3=var_three"]
-    kv_test_property_name = "kv_test_property"
-    pipeline_json = _read_pipeline_resource("resources/sample_pipelines/pipeline_valid_with_pipeline_default.json")
-
-    # Mock get_kv_properties() to ensure the "kv_test_property" variable is included in the list
-    mock_kv_property_list = [pipeline_constants.ENV_VARIABLES, kv_test_property_name]
-    monkeypatch.setattr(PipelineDefinition, "get_kv_properties", mock.Mock(return_value=mock_kv_property_list))
-
-    # Mock set_elyra_properties_to_skip() so that a ComponentCache instance is not created unnecessarily
-    monkeypatch.setattr(Node, "set_elyra_properties_to_skip", mock.Mock(return_value=None))
-
+    # Mock the runtime_type of components in order to return an accurate
+    # set of applicable properties from `get_classes_for_component_type`
+    monkeypatch.setattr(Component, "runtime_type", mock.Mock(return_value=RuntimeProcessorType.APACHE_AIRFLOW.name))
     pipeline_definition = PipelineDefinition(pipeline_definition=pipeline_json)
 
     generic_node = None
@@ -180,14 +160,21 @@ def test_propagate_pipeline_default_properties(monkeypatch):
             custom_node_test = node
 
     # Ensure that default properties have been propagated
-    assert generic_node.get_component_parameter(pipeline_constants.ENV_VARIABLES) == kv_list_correct
-    assert generic_node.get_component_parameter(kv_test_property_name) == kv_list_correct
+    generic_envs = generic_node.get_component_parameter(pipeline_constants.ENV_VARIABLES)
+    assert generic_envs.to_dict() == kv_dict
+    assert generic_node.get_component_parameter(RUNTIME_IMAGE) == "{{ default_image }}"
 
     # Ensure that runtime image and env vars are not propagated to custom components
     assert custom_node_test.get_component_parameter(RUNTIME_IMAGE) is None
     assert custom_node_derive1.get_component_parameter(RUNTIME_IMAGE) is None
     assert custom_node_derive2.get_component_parameter(ENV_VARIABLES) is None
 
+    # Ensure DisableNodeCaching is propagated to all custom components
+    assert generic_node.get_component_parameter(DISABLE_NODE_CACHING) is None
+    assert custom_node_test.get_component_parameter(DISABLE_NODE_CACHING).selection is True
+    assert custom_node_derive1.get_component_parameter(DISABLE_NODE_CACHING).selection is False
+    assert custom_node_derive2.get_component_parameter(DISABLE_NODE_CACHING).selection is False
+
 
 @pytest.mark.parametrize("catalog_instance", [AIRFLOW_TEST_OPERATOR_CATALOG], indirect=True)
 def test_property_id_collision_with_system_property(monkeypatch, catalog_instance):
@@ -207,22 +194,24 @@ def test_property_id_collision_with_system_property(monkeypatch, catalog_instanc
 
     # DeriveFromTestOperator does not define its own 'mounted_volumes'
     # property and should not skip the Elyra 'mounted_volumes' property
-    assert MOUNTED_VOLUMES not in custom_node_derive1.elyra_properties_to_skip
-    assert MOUNTED_VOLUMES not in custom_node_derive2.elyra_properties_to_skip
+    assert MOUNTED_VOLUMES in custom_node_derive1.elyra_owned_properties
+    assert MOUNTED_VOLUMES in custom_node_derive2.elyra_owned_properties
 
     # Property value should be a combination of the lists given on the
     # pipeline node and in the pipeline default properties
-    assert custom_node_derive1.get_component_parameter(MOUNTED_VOLUMES) == [
-        VolumeMount(path="/mnt/vol2", pvc_name="pvc-claim-2"),
-        VolumeMount(path="/mnt/vol1", pvc_name="pvc-claim-1"),
-    ]
-    assert custom_node_derive2.get_component_parameter(MOUNTED_VOLUMES) == [
-        VolumeMount(path="/mnt/vol2", pvc_name="pvc-claim-2")
-    ]
+    derive1_vols = custom_node_derive1.get_component_parameter(MOUNTED_VOLUMES)
+    assert derive1_vols.to_dict() == {
+        "/mnt/vol2": {"path": "/mnt/vol2", "pvc_name": "pvc-claim-2", "read_only": None, "sub_path": None},
+        "/mnt/vol1": {"path": "/mnt/vol1", "pvc_name": "pvc-claim-1", "read_only": None, "sub_path": None},
+    }
+    derive2_vols = custom_node_derive2.get_component_parameter(MOUNTED_VOLUMES)
+    assert derive2_vols.to_dict() == {
+        "/mnt/vol2": {"path": "/mnt/vol2", "pvc_name": "pvc-claim-2", "read_only": None, "sub_path": None}
+    }
 
-    # TestOperator defines its own 'mounted_volumes' property
+    # TestOperator defines its own "mounted_volumes" property
     # and should skip the Elyra system property of the same name
-    assert MOUNTED_VOLUMES in custom_node_test.elyra_properties_to_skip
+    assert MOUNTED_VOLUMES not in custom_node_test.elyra_owned_properties
 
     # Property value should be as-assigned in pipeline file
     assert custom_node_test.get_component_parameter(MOUNTED_VOLUMES) == "a component-parsed property"
@@ -232,7 +221,8 @@ def test_remove_env_vars_with_matching_secrets(monkeypatch):
     pipeline_json = _read_pipeline_resource("resources/sample_pipelines/pipeline_valid_with_pipeline_default.json")
 
     # Mock set_elyra_properties_to_skip() so that a ComponentCache instance is not created unnecessarily
-    monkeypatch.setattr(Node, "set_elyra_properties_to_skip", mock.Mock(return_value=None))
+    monkeypatch.setattr(Node, "set_elyra_owned_properties", mock.Mock(return_value=None))
+    monkeypatch.setattr(Node, "elyra_owned_properties", {KUBERNETES_SECRETS, ENV_VARIABLES})
 
     pipeline_definition = PipelineDefinition(pipeline_definition=pipeline_json)
     node = None
@@ -241,9 +231,14 @@ def test_remove_env_vars_with_matching_secrets(monkeypatch):
             break
 
     # Set kubernetes_secret property to have all the same keys as those in the env_vars property
-    kubernetes_secrets = KeyValueList(["var1=name1:key1", "var2=name2:key2", "var3=name3:key3"])
+    kubernetes_secrets = ElyraPropertyList(
+        [
+            KubernetesSecret(env_var="var1", name="name1", key="key1"),
+            KubernetesSecret(env_var="var2", name="name2", key="key2"),
+            KubernetesSecret(env_var="var3", name="name3", key="key3"),
+        ]
+    )
     node.set_component_parameter(KUBERNETES_SECRETS, kubernetes_secrets)
-
     node.remove_env_vars_with_matching_secrets()
     assert node.get_component_parameter(ENV_VARIABLES) == []
 
