@@ -13,19 +13,24 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from conftest import AIRFLOW_TEST_OPERATOR_CATALOG
 import pytest
 
+from elyra.pipeline.component_parameter import ElyraPropertyList
+from elyra.pipeline.component_parameter import EnvironmentVariable
 from elyra.pipeline.parser import PipelineParser
 from elyra.pipeline.pipeline import GenericOperation
+from elyra.pipeline.pipeline_constants import ENV_VARIABLES
+from elyra.pipeline.pipeline_constants import MOUNTED_VOLUMES
 from elyra.tests.pipeline.util import _read_pipeline_resource
 
 
 @pytest.fixture
 def valid_operation():
+    env_vars = [EnvironmentVariable(env_var="var1", value="var1"), EnvironmentVariable(env_var="var2", value="var2")]
     component_parameters = {
         "filename": "{{filename}}",
         "runtime_image": "{{runtime_image}}",
-        "env_vars": ["var1=var1", "var2=var2"],
         "dependencies": ["a.txt", "b.txt", "c.txt"],
         "outputs": ["d.txt", "e.txt", "f.txt"],
     }
@@ -35,6 +40,7 @@ def valid_operation():
         classifier="execute-notebook-node",
         name="{{label}}",
         component_params=component_parameters,
+        elyra_params={"env_vars": ElyraPropertyList(env_vars)},
     )
 
 
@@ -47,6 +53,11 @@ def test_valid_pipeline(valid_operation):
     assert pipeline.runtime == "{{runtime}}"
     assert pipeline.runtime_config == "{{runtime-config}}"
     assert len(pipeline.operations) == 1
+
+    pipeline_op_envs = pipeline.operations["{{uuid}}"].elyra_params.pop(ENV_VARIABLES)
+    valid_op_envs = valid_operation.elyra_params.pop(ENV_VARIABLES)
+    assert pipeline_op_envs.to_dict() == valid_op_envs.to_dict()
+
     assert pipeline.operations["{{uuid}}"] == valid_operation
 
 
@@ -59,6 +70,11 @@ def test_pipeline_with_dirty_list_values(valid_operation):
     assert pipeline.runtime == "{{runtime}}"
     assert pipeline.runtime_config == "{{runtime-config}}"
     assert len(pipeline.operations) == 1
+
+    pipeline_op_envs = pipeline.operations["{{uuid}}"].elyra_params.pop(ENV_VARIABLES)
+    valid_op_envs = valid_operation.elyra_params.pop(ENV_VARIABLES)
+    assert pipeline_op_envs.to_dict() == valid_op_envs.to_dict()
+
     assert pipeline.operations["{{uuid}}"] == valid_operation
 
 
@@ -176,11 +192,12 @@ def test_missing_pipeline_runtime():
 def test_missing_pipeline_runtime_configuration():
     pipeline_json = _read_pipeline_resource("resources/sample_pipelines/pipeline_valid.json")
     pipeline_json["pipelines"][0]["app_data"].pop("runtime_config")
+    # emulate what validation will do when there's no value for runtime_config...
+    pipeline_json["pipelines"][0]["app_data"]["runtime"] = "local"
 
-    with pytest.raises(ValueError) as e:
-        PipelineParser().parse(pipeline_json)
-
-    assert "Invalid pipeline: Missing runtime configuration" in str(e.value)
+    pipeline = PipelineParser().parse(pipeline_json)
+    assert pipeline.runtime == "local"
+    assert pipeline.runtime_config is None
 
 
 def test_missing_operation_id():
@@ -231,3 +248,22 @@ def test_missing_operation_image():
         PipelineParser().parse(pipeline_json)
 
     assert "Missing field 'operation runtime image'" in str(e.value)
+
+
+@pytest.mark.parametrize("catalog_instance", [AIRFLOW_TEST_OPERATOR_CATALOG], indirect=True)
+def test_custom_component_parsed_properties(monkeypatch, catalog_instance):
+    pipeline_json = _read_pipeline_resource("resources/sample_pipelines/pipeline_with_airflow_components.json")
+    parsed_pipeline = PipelineParser().parse(pipeline_json)
+
+    operation_id = "bb9473ca-12ec-0472-a36a-45bd2a1f6dc1"
+    custom_op = parsed_pipeline.operations[operation_id]
+
+    # Ensure this operation's component params does not include the empty mounted volumes list
+    assert custom_op.elyra_params.get(MOUNTED_VOLUMES) == []
+
+    operation_id = "bb9606ca-29ec-4133-a36a-67bd2a1f6dc3"
+    custom_op = parsed_pipeline.operations[operation_id]
+
+    # Ensure this operation's component params includes the value for the component-defined mounted volumes property
+    assert custom_op.component_params_as_dict.get(MOUNTED_VOLUMES)["value"] == "a component-defined property"
+    assert custom_op.elyra_params.get(MOUNTED_VOLUMES) is None
